class CargoDeps < Formula
  desc "Cargo subcommand to building dependency graphs of Rust projects"
  homepage "https://crates.io/crates/cargo-deps"
  url "https://static.crates.io/crates/cargo-deps/cargo-deps-1.5.1.crate"
  sha256 "958e78d8463edf62018d7d5e6f1c5866d59084a4f224c3be01f6eca8a2d3df47"
  license "BSD-3-Clause"

  deprecate! date: "2024-01-19", because: :repo_removed

  depends_on "rust" => :build
  depends_on "rustup" => :test

  def install
    system "cargo", "install", *std_cargo_args
  end

  test do
    # Show that we can use a different toolchain than the one provided by the `rust` formula.
    # https://github.com/Homebrew/homebrew-core/pull/134074#pullrequestreview-1484979359
    ENV.prepend_path "PATH", Formula["rustup"].bin
    system "rustup", "default", "beta"
    system "rustup", "set", "profile", "minimal"

    crate = testpath/"demo-crate"
    mkdir crate do
      (crate/"src/main.rs").write <<~EOS
        fn main() {
          println!("Hello BrewTestBot!");
        }
      EOS
      (crate/"Cargo.toml").write <<~EOS
        [package]
        name = "demo-crate"
        version = "0.1.0"
        license = "MIT"
      EOS

      system "cargo", "generate-lockfile"

      output = shell_output("cargo deps")
      assert_match "digraph dependencies", output

      output = shell_output("#{bin}/cargo-deps --version")
      assert_match "cargo-deps #{version}", output
    end
  end
end
